//
//  DFTConnection.m
//  SoundShare
//
//  Created by Michael Rotondo on 2/21/12.
//  Copyright (c) 2012 Rototyping. All rights reserved.
//

#import "DFTConnection.h"
#import "AFJSONRequestOperation.h"

NSString * const kSoundShareBaseURLString = @"http://arthur.stanford.edu:80/";

@implementation DFTConnection

+ (DFTConnection *)sharedClient
{
    static DFTConnection *_sharedClient = nil;
    static dispatch_once_t oncePredicate;
    dispatch_once(&oncePredicate, ^{
        _sharedClient = [[self alloc] initWithBaseURL:[NSURL URLWithString:kSoundShareBaseURLString]];
    });
    
    return _sharedClient;
}

- (id)initWithBaseURL:(NSURL *)url
{
    self = [super initWithBaseURL:url];
    if (!self) {
        return nil;
    }
    
    [self registerHTTPOperationClass:[AFJSONRequestOperation class]];
    
    // Accept HTTP Header; see http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.1
	[self setDefaultHeader:@"Accept" value:@"application/json"];
    	
	// X-UDID HTTP Header
	[self setDefaultHeader:@"X-UDID" value:[[UIDevice currentDevice] uniqueIdentifier]];
    
    return self;
}

- (void) uploadWithFilePath:(NSString *)path withParams:(NSMutableDictionary *)params
{
    NSMutableURLRequest *myRequest = [self multipartFormRequestWithMethod:@"POST" path:@"tour/mediapair" parameters:params constructingBodyWithBlock: ^(id <AFMultipartFormData>formData) {
        
        NSData *fileData=[NSData dataWithContentsOfFile:path];
        
        [formData appendPartWithFileData:fileData name:@"mediafile" fileName:nil mimeType:@"application/octet-stream"];
        
        //        NSURL *fileURL = [[NSBundle mainBundle] URLForResource:@"temp4" withExtension:@"wav"];
        //        NSData *fileData = [NSData dataWithContentsOfURL:fileURL];
        
        //        [formData appendPartWithFileData:fileData name:@"soundfile" fileName:@"temp4.wav" mimeType:@"audio/wav"];
    }];
    AFHTTPRequestOperation *uploadOperation = [[AFHTTPRequestOperation alloc] initWithRequest:myRequest];
    [uploadOperation setCompletionBlockWithSuccess:^(AFHTTPRequestOperation *operation, id responseObject) {
        return;
    } failure:^(AFHTTPRequestOperation *operation, NSError *error) {
        NSLog(@"FAILURE TO UPLOAD: %@", error);
    }];
    
    NSOperationQueue *queue = [NSOperationQueue mainQueue];
    [queue addOperation:uploadOperation];

}

- (void) uploadPairWithImgPath:(NSString*)img_path withAudioPath:(NSString*)audio_path withParams:(NSMutableDictionary*)params
{
    NSMutableURLRequest *myRequest = [self multipartFormRequestWithMethod:@"POST" path:@"tour/mediapair" parameters:params constructingBodyWithBlock: ^(id <AFMultipartFormData>formData) {
        
        NSData *img_data=[NSData dataWithContentsOfFile:img_path];
        NSData *audio_data=[NSData dataWithContentsOfFile:audio_path];
        
        [formData appendPartWithFileData:img_data name:@"img_file" fileName:nil mimeType:@"application/octet-stream"];
        [formData appendPartWithFileData:audio_data name:@"audio_file" fileName:nil mimeType:@"application/octet-stream"];
        
    }];
    AFHTTPRequestOperation *uploadOperation = [[AFHTTPRequestOperation alloc] initWithRequest:myRequest];
    [uploadOperation setCompletionBlockWithSuccess:^(AFHTTPRequestOperation *operation, id responseObject) {
        return;
    } failure:^(AFHTTPRequestOperation *operation, NSError *error) {
        NSLog(@"FAILURE TO UPLOAD: %@", error);
//        NSLog(@"[Error]: (%@ %@) %@\nresponse: %@", [operation.request HTTPMethod], [[operation.request URL] relativePath], operation.error, operation.responseString);
    }];
    
    NSOperationQueue *queue = [NSOperationQueue mainQueue];
    [queue addOperation:uploadOperation];
}
@end
